@@ -19,6 +19,8 @@
 #include <KAuthActionReply>
 #include <QObject>
 
+using namespace KAuth;
+
 namespace K3b {
  
 class Helper : public QObject
@@ -36,14 +38,14 @@ public slots:
      * @param programs list of the programs which will have updated permissions. Each element
      *                 of the list is a @see K3b::HelperProgramItem object
      */
-    KAuth::ActionReply updatepermissions( QVariantMap args );
+    ActionReply updatepermissions( QVariantMap args );
 
     /**
      * Adds user to a specified group
      * @param groupName name of the group
      * @param userName name of the user
      */
-    KAuth::ActionReply addtogroup( QVariantMap args );
+    ActionReply addtogroup( QVariantMap args );
 };
 
 } // namespace K3b
